
import mcujavasource.mcu.*;
import mcujavasource.mcu.external.led.MultiDigitLedDisplay;

/** Tutorial 8: multi digit LED display.
 * At the beginning, number 0000 is displayed.
 * First digit increments, then second after delay, third, fourth. First digit 
 * increments again. Program is repeated discontiniously.
 */
public class Main extends Microcontroller
{
  private MultiDigitLedDisplay ledDisplay;
  private Port segmentPort = getHardware().getPort("D");
  private Port commonPort = getHardware().getPort("C");
  private Pin common0 = commonPort.getPin(1);
  private Pin common1 = commonPort.getPin(2);
  private Pin common2 = commonPort.getPin(3);
  private Pin common3 = commonPort.getPin(4);
  
  private Timer ledDisplayTimer;
  
  public void init()
  { getHardware().setAllPortsDirection(Pin.IN);
	getHardware().setAllPortsPullUp(true);
	ledDisplay = new MultiDigitLedDisplay(true, //common anode
        segmentPort, common0, common1, common2, common3);
	ledDisplayTimer = getHardware().getDefaultTimer(8);
	ledDisplayTimer.setMode(TimerMode.NORMAL);
	ledDisplayTimer.setPrescaling(8);
	ledDisplayTimer.setEnabled(true);
	LedDisplayDigitMultiplexer multiplexer = new LedDisplayDigitMultiplexer();
	ledDisplayTimer.addTimerListener(multiplexer);
	ledDisplayTimer.setTimerOverflowedFired(true);
  }
  
  public void start()
  { ledDisplay.setDigitValue(0, 0);
	ledDisplay.setDigitValue(1, 0);
	ledDisplay.setDigitValue(2, 0);
	ledDisplay.setDigitValue(3, 0);
	getHardware().setInterruptsEnabled(true);
    for(;;)
    { for(int digit = 0; digit < 4; digit++)
      { int value = ledDisplay.getDigitValue(digit);
        if(++value > 10) value = 0;
        ledDisplay.setDigitValue(digit, value);
        getHardware().getDelay().sleep(250);
      }
    }
  }
  
  private class LedDisplayDigitMultiplexer implements TimerListener
  {
	public void timerOverflowed()
	{ ledDisplay.processMultiplexing(); 
	}
	
  }
  
  
}

